﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Net;
using System.IO;
using System.Xml;
using System.Web;
using System.Threading;

namespace WordpressPlugin
{
    /// <summary>
    /// The form that shows comments from the users blog
    /// </summary>
    public partial class CommentForm : Form
    {
        public CommentForm()
        {
            InitializeComponent();
        }

        private readonly BlogContext BlogContext;

        public CommentForm(BlogContext context)
        {
            InitializeComponent();
            BlogContext = context;            
            Text = "Comment management for " + context.PublishingContext.BlogName;
            UpdateComments(commentTabControl.NewTabPage);
        }

        private void UpdateComments(CommentTabPage commentTabPage)
        {
            // If its already loading, don't update.
            if (commentTabPage.Loading)
                return;

            CommentBackgroundWorker worker = new CommentBackgroundWorker(commentTabPage, BlogContext);
            worker.RunWorkerAsync();
        }

        private void commentsTabControl_Selected(object sender, TabControlEventArgs e)
        {
            CommentTabPage commentTabPage = e.TabPage as CommentTabPage;
            if(commentTabPage != null)
                UpdateComments(commentTabPage);
        }
    }

    public class Comment
    {
        public string Date;
        public string PostTitle;
        public string Link;
        public string Content;
        public string CommandId;
        public string Author;
        public string AuthorUrl;
        public string AuthorEmail;
        public CommentStatus Status;

        public static bool ChangeCommentStatus(BlogContext blogContext, Comment c, CommentStatus status)
        {
            // If status is the same, we don't need to update anything
            if (c.Status == status)
                return false;

            // Put the network request on a background thread
            Thread t = new Thread(() =>
            {
                try
                {
                    XmlRpcHelper.WpEditComment(blogContext, c, status);
                }
                catch (OperationCanceledException)
                {
                    return;
                }
            });

            t.Start();

            // True means we changed the status so so we need to remove it from the form
            return true;
        }
    }

    public enum CommentStatus
    {
        approve, // Normal comment
        hold, // Waiting for moderation
        spam, // Marked as spam
        delete // Remove the comment
    }
}
