﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;

namespace WordpressPlugin
{
    public class CommentTabPage : TabPage
    {
        private static object syncObject = new Object();
        private bool loading;
        private TableLayoutPanel tableLayoutPanel;

        private Label loadingLabel = new Label()
        {
            Dock = DockStyle.Fill,
            Text = "Loading...",
            TextAlign = System.Drawing.ContentAlignment.MiddleCenter
        };

        private Label noCommentsToShowLabel = new Label()
        {
            Dock = DockStyle.Fill,
            Text = "No comments to show.",
            TextAlign = System.Drawing.ContentAlignment.MiddleCenter
        };

        public bool Loading 
        {
            get
            {
                lock (syncObject)
                {
                    return loading;
                }
            }
            set
            {
                lock (syncObject)
                {
                    loading = value;

                    if (loading)
                    {
                        Controls.Clear();
                        tableLayoutPanel.Controls.Clear();
                        Controls.Add(loadingLabel);
                    }
                    else if (!loading && Controls.Count == 1 && Controls.Contains(loadingLabel))
                    {
                        Controls.Remove(loadingLabel);
                        Controls.Add(noCommentsToShowLabel);
                    }
                }
            }
        }

        public CommentStatus Status { get; private set; }

        public CommentTabPage(CommentStatus status)
        {
            InitializeComponent();

            Status = status;
        }

        protected override void OnSizeChanged(EventArgs e)
        {
            base.OnSizeChanged(e);

            loadingLabel.Size = Size;
            noCommentsToShowLabel.Size = Size;
            tableLayoutPanel.Size = Size;
        }

        public void AddComment(CommentControl commentControl)
        {
            Controls.Remove(loadingLabel);
            Controls.Remove(noCommentsToShowLabel);

            if (!Controls.Contains(tableLayoutPanel))
                Controls.Add(tableLayoutPanel);

            tableLayoutPanel.Controls.Add(commentControl);
        }

        public void RemoveComment(CommentControl commentControl)
        {
            tableLayoutPanel.Controls.Remove(commentControl);

            if (tableLayoutPanel.Controls.Count == 0)
            {
                Controls.Remove(tableLayoutPanel);
                Controls.Add(noCommentsToShowLabel);
            }
        }

        // Designer generated code.
        private void InitializeComponent()
        {
            this.tableLayoutPanel = new System.Windows.Forms.TableLayoutPanel();
            this.SuspendLayout();
            // 
            // tableLayoutPanel
            // 
            this.tableLayoutPanel.AutoScroll = true;
            this.tableLayoutPanel.ColumnCount = 1;
            this.tableLayoutPanel.ColumnStyles.Add(new System.Windows.Forms.ColumnStyle(System.Windows.Forms.SizeType.Percent, 100F));
            this.tableLayoutPanel.Location = new System.Drawing.Point(0, 0);
            this.tableLayoutPanel.Margin = new System.Windows.Forms.Padding(0,0,0,10);
            this.tableLayoutPanel.Name = "tableLayoutPanel";
            this.tableLayoutPanel.RowCount = 1;
            this.tableLayoutPanel.RowStyles.Add(new System.Windows.Forms.RowStyle());
            this.tableLayoutPanel.Size = new System.Drawing.Size(470, 100);
            this.tableLayoutPanel.TabIndex = 0;
            this.ResumeLayout(false);

        }
    }
}
