﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Net;
using System.Runtime.InteropServices;
using System.Text;
using System.Web;
using System.Windows.Forms;
using System.Xml;
using WindowsLive.Writer.Api;

namespace WordpressPlugin
{
    public partial class TaglineDialog : Form
    {
        public TaglineDialog()
        {
            InitializeComponent();
        }

        BlogContext BlogContext;
        private IProperties properties;

        // Message to set a cue banner on a textbox
        private const int EM_SETCUEBANNER = 0x1501;
        [DllImport("user32.dll", CharSet = CharSet.Unicode)]
        private static extern Int32 SendMessage(IntPtr hWnd, int msg,int wParam, [MarshalAs(UnmanagedType.LPWStr)] string lParam);

        public TaglineDialog(BlogContext context, IProperties properties)
        {
            InitializeComponent();
            BlogContext = context;
            this.properties = properties;

            // Set cue banner to prompt the user to enter their username
            SendMessage(textBoxTwitterName.Handle, EM_SETCUEBANNER, 0, "Enter Twitter Name");
            
            Text = "Edit blog title and tagline for " + context.PublishingContext.BlogName;
        }

        protected override void OnLoad(EventArgs e)
        {
            base.OnLoad(e);

            XmlDocument doc = null;
            
            try
            {
                doc = XmlRpcHelper.WpGetOptions(BlogContext);
            }
            catch (OperationCanceledException)
            {
                // If we failed to get the blog tagline, just close the form right away
                DialogResult = DialogResult.Cancel;
                Close();
                return;
            }

            // Pull out the values of properties we queried, both of these values needed to be html decoded
            // becuase they they are displayed on blogs
            XmlNodeList options = doc.SelectNodes("//methodResponse/params/param/value/struct/member");
            foreach (XmlNode option in options)
            {
                if (XmlRpcHelper.GetInnerTextSafe(option.SelectSingleNode("./name")) == "blog_tagline")
                {
                    XmlNode node = option.SelectSingleNode("./value/struct");
                    foreach (XmlNode prop in node.ChildNodes)
                    {
                        if (XmlRpcHelper.GetInnerTextSafe(prop.SelectSingleNode("./name")) == "value")
                        {
                            textBoxTagline.Text = HttpUtility.HtmlDecode(XmlRpcHelper.GetInnerTextSafe(prop.SelectSingleNode("./value")));
                        }
                    }
                    
                }

                if (XmlRpcHelper.GetInnerTextSafe(option.SelectSingleNode("./name")) == "blog_title")
                {
                    XmlNode node = option.SelectSingleNode("./value/struct");
                    foreach (XmlNode prop in node.ChildNodes)
                    {
                        if (XmlRpcHelper.GetInnerTextSafe(prop.SelectSingleNode("./name")) == "value")
                        {
                            textBoxBlogName.Text = HttpUtility.HtmlDecode(XmlRpcHelper.GetInnerTextSafe(prop.SelectSingleNode("./value")));
                        }
                    }

                }
            }
            
            // Look to see if the user has already used the twitter feature once before
            string twitterName = properties.GetString("twitter_name", null);

            if (!string.IsNullOrEmpty(twitterName))
                textBoxTwitterName.Text = twitterName;

        }

        private void buttonCancel_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void buttonSave_Click(object sender, EventArgs e)
        {
            try
            {
                XmlRpcHelper.WpSetOptions(BlogContext, HttpUtility.HtmlEncode(textBoxBlogName.Text), HttpUtility.HtmlEncode(textBoxTagline.Text));
                Close();
            }
            catch (OperationCanceledException)
            {

            }
        }

        private void button1_Click(object sender, EventArgs e)
        {
            properties.SetString("twitter_name", textBoxTwitterName.Text);

            // Download the twitter feed for that username
            WebClient wc = new WebClient();
            string url = String.Format("http://twitter.com/statuses/user_timeline/{0}.xml", textBoxTwitterName.Text);
            string xml = "";

            try
            {
                xml = wc.DownloadString(url);
            }
            catch (Exception)
            {
                return;
            }


            XmlDocument doc = new XmlDocument();
            doc.LoadXml(xml);
            XmlNodeList list = doc.SelectNodes("//statuses/status/text");

            // Set the status to the latest tweet that wasn't an @ reply or a link to something else
            foreach(XmlNode node in list)
            {
                string status = XmlRpcHelper.GetInnerTextSafe(node);
                if(status.Contains("@") || status.ToLower().Contains("http:"))
                    continue;

                textBoxTagline.Text = status;
                return;

            }

        }

        private void textBoxTwitterName_TextChanged(object sender, EventArgs e)
        {
            // We only want to allow users to import twitter statuses when they enter a twitter name
            button1.Enabled = !string.IsNullOrEmpty(textBoxTwitterName.Text);

        }
    }
}
